@@ -60,6 +60,26 @@ module Sequel
       # Sequel will not check the number of rows modified (default: true).
       attr_accessor :require_modification
   
+      # Requires that all models have valid tables, raising exceptions if creating a model
+      # without a valid table backing it.  Enabling this will break code like:
+      #
+      #   class Foo < Sequel::Model
+      #     set_dataset :my_foo
+      #   end
+      #
+      # As when Sequel::Model is subclassed, before set_dataset is executed, it will try to
+      # get the schema for the foos table, which will raise an exception.  You would need to
+      # switch to using:
+      #
+      #   class Foo < Sequel::Model(:my_foo)
+      #   end
+      #
+      # or:
+      #
+      #   Foo = Sequel::Model()
+      #   Foo.set_dataset :my_foo
+      attr_accessor :require_valid_table
+
       # Should be the literal primary key column name if this Model's table has a simple primary key, or
       # nil if the model has a compound primary key or no primary key.
       attr_reader :simple_pk
@@ -513,10 +533,10 @@ module Sequel
 
         unless ivs.include?("@dataset")
           if @dataset && self != Model
-            subclass.set_dataset(@dataset.clone, :inherited=>true) rescue nil
+            subclass.set_dataset(@dataset.clone, :inherited=>true)
           elsif (n = subclass.name) && !n.to_s.empty?
             db
-            subclass.set_dataset(subclass.implicit_table_name) rescue nil
+            subclass.set_dataset(subclass.implicit_table_name)
           end
         end
       end
@@ -689,12 +709,14 @@ module Sequel
         @require_modification = Sequel::Model.require_modification.nil? ? @dataset.provides_accurate_rows_matched? : Sequel::Model.require_modification
         if inherited
           self.simple_table = superclass.simple_table
-          @columns = @dataset.columns rescue nil
+          @columns = superclass.instance_variable_get(:@columns)
+          @db_schema = superclass.instance_variable_get(:@db_schema)
         else
           @dataset_method_modules.each{|m| @dataset.extend(m)} if @dataset_method_modules
+          @db_schema = get_db_schema
         end
+
         @dataset.model = self if @dataset.respond_to?(:model=)
-        check_non_connection_error{@db_schema = (inherited ? superclass.db_schema : get_db_schema)}
         reset_instance_dataset
         self
       end
@@ -798,11 +820,11 @@ module Sequel
       # Yield to the passed block and swallow all errors other than DatabaseConnectionErrors.
       def check_non_connection_error
         begin
-          yield
+          db.transaction(:savepoint=>:only){yield}
         rescue Sequel::DatabaseConnectionError
           raise
-        rescue
-          nil
+        rescue Sequel::Error
+          raise if require_valid_table
         end
       end
 
